@@ -11,17 +11,19 @@
 #'          or \code{\link{rec_pattern}} and \code{\link{rec}} for another
 #'          convenbient way of recoding variables into smaller groups.
 #'
-#' @param groupsize Numeric; group-size, i.e. the range for grouping. By default,
-#'          for each 5 categories of \code{x} a new group is defined, i.e. \code{groupsize=5}.
-#'          Use \code{groupsize = "auto"} to automatically resize a variable into
+#' @param size Numeric; group-size, i.e. the range for grouping. By default,
+#'          for each 5 categories of \code{x} a new group is defined, i.e. \code{size = 5}.
+#'          Use \code{size = "auto"} to automatically resize a variable into
 #'          a maximum of 30 groups (which is the ggplot-default grouping when
-#'          plotting histograms). Use \code{groupcount} to determine the amount
+#'          plotting histograms). Use \code{n} to determine the amount
 #'          of groups.
 #' @param right.interval Logical; if \code{TRUE}, grouping starts with the lower
-#'          bound of \code{groupsize}. See 'Details'.
-#' @param groupcount Sets the maximum number of groups that are defined when auto-grouping is on
-#'          (\code{groupsize="auto"}). Default is 30. If \code{groupsize} is not set to \code{"auto"},
+#'          bound of \code{size}. See 'Details'.
+#' @param n Sets the maximum number of groups that are defined when auto-grouping is on
+#'          (\code{size = "auto"}). Default is 30. If \code{size} is not set to \code{"auto"},
 #'          this argument will be ignored.
+#' @param groupsize Deprecated. Use \code{size} instead.
+#' @param groupcount Deprecated. Use \code{n} instead.
 #'
 #' @inheritParams to_factor
 #' @inheritParams rec
@@ -32,26 +34,26 @@
 #'         }
 #'
 #' @note Variable label attributes (see, for instance, \code{\link[sjlabelled]{set_label}}) are preserved.
-#'       Usually you should use the same values for \code{groupsize} and
+#'       Usually you should use the same values for \code{size} and
 #'       \code{right.interval} in \code{group_label()} as used in the
 #'       \code{group_var} function if you want matching labels for the related
 #'       recoded variable.
 #'
-#' @details If \code{groupsize} is set to a specific value, the variable is recoded
-#'            into several groups, where each group has a maximum range of \code{groupsize}.
+#' @details If \code{size} is set to a specific value, the variable is recoded
+#'            into several groups, where each group has a maximum range of \code{size}.
 #'            Hence, the amount of groups differ depending on the range of \code{x}.
 #'            \cr \cr
-#'            If \code{groupsize = "auto"}, the variable is recoded into a maximum of
-#'            \code{groupcount} groups. Hence, independent from the range of
+#'            If \code{size = "auto"}, the variable is recoded into a maximum of
+#'            \code{n} groups. Hence, independent from the range of
 #'            \code{x}, always the same amount of groups are created, so the range
 #'            within each group differs (depending on \code{x}'s range).
 #'            \cr \cr
 #'            \code{right.interval} determins which boundary values to include when
 #'            grouping is done. If \code{TRUE}, grouping starts with the \strong{lower
-#'            bound} of \code{groupsize}. For example, having a variable ranging from
+#'            bound} of \code{size}. For example, having a variable ranging from
 #'            50 to 80, groups cover the ranges from  50-54, 55-59, 60-64 etc.
 #'            If \code{FALSE} (default), grouping starts with the \code{upper bound}
-#'            of \code{groupsize}. In this case, groups cover the ranges from
+#'            of \code{size}. In this case, groups cover the ranges from
 #'            46-50, 51-55, 56-60, 61-65 etc. \strong{Note:} This will cover
 #'            a range from 46-50 as first group, even if values from 46 to 49
 #'            are not present. See 'Examples'.
@@ -59,14 +61,19 @@
 #'            If you want to split a variable into a certain amount of equal
 #'            sized groups (instead of having groups where values have all the same
 #'            range), use the \code{\link{split_var}} function!
+#'            \cr \cr
+#'            \code{group_var()} also works on grouped data frames (see \code{\link[dplyr]{group_by}}).
+#'            In this case, grouping is applied to the subsets of variables
+#'            in \code{x}. See 'Examples'.
+#'
 #'
 #' @examples
 #' age <- abs(round(rnorm(100, 65, 20)))
-#' age.grp <- group_var(age, groupsize = 10)
+#' age.grp <- group_var(age, size = 10)
 #' hist(age)
 #' hist(age.grp)
 #'
-#' age.grpvar <- group_labels(age, groupsize = 10)
+#' age.grpvar <- group_labels(age, size = 10)
 #' table(age.grp)
 #' print(age.grpvar)
 #'
@@ -86,7 +93,7 @@
 #' library(dplyr)
 #' efc %>%
 #'   select(e17age, c12hour, c160age) %>%
-#'   group_var(groupsize = 20)
+#'   group_var(size = 20)
 #'
 #' # create vector with values from 50 to 80
 #' dummy <- round(runif(200, 50, 80))
@@ -95,10 +102,33 @@
 #' # labels with grouping startint at upper bound
 #' group_labels(dummy, right.interval = TRUE)
 #'
+#' # works also with gouped data frames
+#' mtcars %>%
+#'   group_var(disp, size = 4) %>%
+#'   table()
+#'
+#' mtcars %>%
+#'   group_by(cyl) %>%
+#'   group_var(disp, size = 4) %>%
+#'   table()
+#'
 #' @importFrom purrr map
 #' @export
-group_var <- function(x, ..., groupsize = 5, as.num = TRUE, right.interval = FALSE,
-                      groupcount = 30, append = FALSE, suffix = "_gr") {
+group_var <- function(x, ..., size = 5, as.num = TRUE, right.interval = FALSE,
+                      n = 30, append = FALSE, suffix = "_gr", groupsize, groupcount) {
+
+  # check deprecated arguments
+  if (!missing(groupcount)) {
+    message("Argument `groupcount` is deprecated. Please use `n` instead.")
+    n <- groupcount
+  }
+
+  if (!missing(groupsize)) {
+    message("Argument `groupsize` is deprecated. Please use `size` instead.")
+    size <- groupsize
+  }
+
+
   # evaluate arguments, generate data
   .dat <- get_dot_data(x, dplyr::quos(...))
 
@@ -107,15 +137,49 @@ group_var <- function(x, ..., groupsize = 5, as.num = TRUE, right.interval = FAL
     # remember original data, if user wants to bind columns
     orix <- tibble::as_tibble(x)
 
-    # iterate variables of data frame
-    for (i in colnames(.dat)) {
-      x[[i]] <- g_v_helper(
-        x = .dat[[i]],
-        groupsize = groupsize,
-        as.num = as.num,
-        right.interval = right.interval,
-        groupcount = groupcount
-      )
+    # do we have a grouped data frame?
+    if (inherits(.dat, "grouped_df")) {
+
+      # get grouped data, as nested data frame
+      grps <- get_grouped_data(.dat)
+
+      # iterate all groups
+      for (i in seq_len(nrow(grps))) {
+        # get data from each single group
+        group <- grps$data[[i]]
+
+        # now iterate all variables of interest
+        for (j in colnames(group)) {
+          group[[j]] <- g_v_helper(
+            x = group[[j]],
+            groupsize = size,
+            as.num = as.num,
+            right.interval = right.interval,
+            groupcount = n
+          )
+        }
+
+        # write back data
+        grps$data[[i]] <- group
+      }
+
+      # unnest data frame
+      x <- tidyr::unnest(grps)
+
+      # remove grouping column
+      .dat <- .dat[colnames(.dat) %nin% dplyr::group_vars(.dat)]
+
+    } else {
+      # iterate variables of data frame
+      for (i in colnames(.dat)) {
+        x[[i]] <- g_v_helper(
+          x = .dat[[i]],
+          groupsize = size,
+          as.num = as.num,
+          right.interval = right.interval,
+          groupcount = n
+        )
+      }
     }
 
     # coerce to tibble and select only recoded variables
@@ -131,10 +195,10 @@ group_var <- function(x, ..., groupsize = 5, as.num = TRUE, right.interval = FAL
   } else {
     x <- g_v_helper(
       x = .dat,
-      groupsize = groupsize,
+      groupsize = size,
       as.num = as.num,
       right.interval = right.interval,
-      groupcount = groupcount
+      groupcount = n
     )
   }
 
@@ -164,7 +228,18 @@ g_v_helper <- function(x, groupsize, as.num, right.interval, groupcount) {
 
 #' @rdname group_var
 #' @export
-group_labels <- function(x, ..., groupsize = 5, right.interval = FALSE, groupcount = 30) {
+group_labels <- function(x, ..., size = 5, right.interval = FALSE, n = 30, groupsize, groupcount) {
+  # check deprecated arguments
+  if (!missing(groupcount)) {
+    message("Argument `groupcount` is deprecated. Please use `n` instead.")
+    n <- groupcount
+  }
+
+  if (!missing(groupsize)) {
+    message("Argument `groupsize` is deprecated. Please use `size` instead.")
+    size <- groupsize
+  }
+
   # evaluate arguments, generate data
   .dat <- get_dot_data(x, dplyr::quos(...))
 
@@ -173,17 +248,17 @@ group_labels <- function(x, ..., groupsize = 5, right.interval = FALSE, groupcou
     return(
       purrr::map(.dat, ~ g_l_helper(
         x = .x,
-        groupsize = groupsize,
+        groupsize = size,
         right.interval = right.interval,
-        groupcount = groupcount
+        groupcount = n
     )))
 
   } else {
     x <- g_l_helper(
       x = .dat,
-      groupsize = groupsize,
+      groupsize = size,
       right.interval = right.interval,
-      groupcount = groupcount
+      groupcount = n
     )
   }
 
